==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/vi/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Người dùng này có thể đăng nhập',
    'activated_disabled_help_text' => 'Bạn không thể sửa tình trạng kích hoạt của tài khoản quản trị.',
    'assets_user'       => 'Tài sản đã được cấp phát đến :name',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa các thuộc tính của: user_count users. Xin lưu ý rằng bạn không thể thay đổi thuộc tính người dùng của mình bằng cách sử dụng biểu mẫu này và phải thực hiện chỉnh sửa cho người dùng riêng của mình.',
    'bulk_update_help'	=> 'Biểu mẫu này cho phép bạn cập nhật nhiều người dùng cùng một lúc. Chỉ điền vào các trường mà bạn cần thay đổi. Bất kỳ trường nào để trống sẽ không thay đổi.',
    'current_assets'    => 'Tài sản hiện được kiểm tra cho người dùng này',
    'clone'             => 'Nhân đôi người dùng',
    'contact_user'      => 'Liên hệ :name',
    'edit'              => 'Sửa người dùng',
    'filetype_info'     => 'Cho phép loại tập tin are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Lịch sử cấp phát của :name',
	'info'				=> 'Thông tin',
    'restore_user'		=> 'Nhấp vào đây để khôi phục chúng.',
    'last_login'        => 'Lần đăng nhập trước',
    'ldap_config_text'  => 'Bạn có thể tìm thấy cài đặt cấu hình LDAP Quản trị> Cài đặt. Địa điểm đã chọn (tùy chọn) sẽ được đặt cho tất cả người dùng được nhập.',
    'print_assigned'    => 'In tất cả tài sản đã cấp phát',
    'software_user'     => 'Phần mềm đã được checkout đến :name',
    'send_email_help'   => 'Bạn phải cung cấp địa chỉ email của người dùng để gửi chứng thực. Gửi mail chứng thực chỉ có hiệu lực đối với người dùng tạo ra. Mật khẩu được mã hóa một chiều và không thể lấy lại một khi đã lưu.',
    'view_user'         => 'Xem người dùng :name',
    'usercsv'           => 'Tập tin CSV',
    'two_factor_admin_optin_help' => 'Cài đặt quản trị hiện tại của bạn cho phép thực thi có chọn lọc xác thực hai yếu tố.',
    'two_factor_enrolled' => 'Thiết bị 2FA đã đăng ký',
    'two_factor_active'   => '2FA Hoạt động',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/vi/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Người dùng này có thể đăng nhập',
    'activated_disabled_help_text' => 'Bạn không thể sửa tình trạng kích hoạt của tài khoản quản trị.',
    'assets_user'       => 'Tài sản đã được cấp phát đến :name',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa các thuộc tính của: user_count users. Xin lưu ý rằng bạn không thể thay đổi thuộc tính người dùng của mình bằng cách sử dụng biểu mẫu này và phải thực hiện chỉnh sửa cho người dùng riêng của mình.',
    'bulk_update_help'	=> 'Biểu mẫu này cho phép bạn cập nhật nhiều người dùng cùng một lúc. Chỉ điền vào các trường mà bạn cần thay đổi. Bất kỳ trường nào để trống sẽ không thay đổi.',
    'current_assets'    => 'Tài sản hiện được kiểm tra cho người dùng này',
    'clone'             => 'Nhân đôi người dùng',
    'contact_user'      => 'Liên hệ :name',
    'edit'              => 'Sửa người dùng',
    'filetype_info'     => 'Cho phép loại tập tin are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Lịch sử cấp phát của :name',
    'info'				=> 'Thông tin',
    'restore_user'		=> 'Nhấp vào đây để khôi phục chúng.',
    'last_login'        => 'Lần đăng nhập trước',
    'ldap_config_text'  => 'Bạn có thể tìm thấy cài đặt cấu hình LDAP Quản trị> Cài đặt. Địa điểm đã chọn (tùy chọn) sẽ được đặt cho tất cả người dùng được nhập.',
    'print_assigned'    => 'In tất cả tài sản đã cấp phát',
    'software_user'     => 'Phần mềm đã được checkout đến :name',
    'send_email_help'   => 'Bạn phải cung cấp địa chỉ email của người dùng để gửi chứng thực. Gửi mail chứng thực chỉ có hiệu lực đối với người dùng tạo ra. Mật khẩu được mã hóa một chiều và không thể lấy lại một khi đã lưu.',
    'view_user'         => 'Xem người dùng :name',
    'usercsv'           => 'Tập tin CSV',
    'two_factor_admin_optin_help' => 'Cài đặt quản trị hiện tại của bạn cho phép thực thi có chọn lọc xác thực hai yếu tố.',
    'two_factor_enrolled' => 'Thiết bị 2FA đã đăng ký',
    'two_factor_active'   => '2FA Hoạt động',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
